@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.20;
 use warnings;
 
 use Getopt::Long;
