@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2026 -- leonerd@leonerd.org.uk
 
-package Net::LibAsyncNS::Constants;
+package Net::LibAsyncNS::Constants 0.05;
 
-use strict;
+use v5.20;
 use warnings;
 
-our $VERSION = '0.04';
-
 use Exporter 'import';
 
 # Constants are loaded from Net::LibAsyncNS
